@@ -32,14 +32,19 @@
 #undef HAVE_SETENV
 #undef HAVE_SETRESUID
 #undef HAVE_SHADOW
+#undef HAVE_SMF_CONTRACTS
 #undef HAVE_SOLARIS_XINERAMA
 #undef HAVE_STPCPY
 #undef HAVE_SYS_SOCKIO_H
+#undef HAVE_SYS_VT_H
 #undef HAVE_TCPWRAPPERS
 #undef HAVE_UNSETENV
 #undef HAVE_XINERAMA
 #undef HAVE_XFREE_XINERAMA
 #undef HAVE_XINPUT
+#undef UTMP_LINE_ATTACHED
+#undef UTMP_LINE_REMOTE
+#undef UTMP_PSEUDO_DEVICE
 #undef X_SERVER
 #undef X_SERVER_PATH
 #undef X_XNEST_CMD
@@ -49,3 +54,4 @@
 #undef X_PATH
 #undef XSESSION_SHELL
 #undef XEVIE_OPTION
+#undef HAVE_UT_SYSLEN
