@@ -56,7 +56,10 @@ gdm_get_current_vtnum (Display *display)
 	unsigned char *buf;
 	unsigned long num;
 
-	prop = XInternAtom (display, "XFree86_VT", False);
+	if (display == NULL)
+		return -1;
+
+	prop = XInternAtom (display, "XFree86_VT", True);
 	if (prop == None) {
 	        gdm_debug ("no XFree86_VT atom\n");
 	        return -1;
