@@ -208,6 +208,8 @@ gdm_fdprintf (int fd, const gchar *format, ...)
 /*
  * Clear environment, but keep the i18n ones,
  * note that this leaks memory so only use before exec
+ * Also do not clear DISPLAY since we want to ensure that
+ * this environment variable is always available.
  */
 void
 gdm_clearenv_no_lang (void)
@@ -219,7 +221,8 @@ gdm_clearenv_no_lang (void)
 		char *env = environ[i];
 		if (strncmp (env, "LC_", 3) == 0 ||
 		    strncmp (env, "LANG", 4) == 0 ||
-		    strncmp (env, "LINGUAS", 7) == 0) {
+		    strncmp (env, "LINGUAS", 7) == 0 ||
+		    strncmp (env, "DISPLAY", 7) == 0) {
 			envs = g_list_prepend (envs, g_strdup (env));
 		}
 	}
@@ -862,7 +865,7 @@ ensure_tmp_socket_dir (const char *dir)
                          * There is a file/link/whatever of the same name?
 			 * whack and try mkdir
                          */
-			VE_IGNORE_EINTR (g_unlink (dir));
+			VE_IGNORE_EINTR (g_remove (dir));
 			g_mkdir (dir, 01777);
 		}
 	}
